summaryrefslogtreecommitdiff
path: root/src/script/api/script_grouplist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_grouplist.cpp')
-rw-r--r--src/script/api/script_grouplist.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/script/api/script_grouplist.cpp b/src/script/api/script_grouplist.cpp
index 017af8b8a..cbaeea0ac 100644
--- a/src/script/api/script_grouplist.cpp
+++ b/src/script/api/script_grouplist.cpp
@@ -7,14 +7,14 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file script_grouplist.cpp Implementation of AIGroupList and friends. */
#include "../../stdafx.h"
#include "script_grouplist.hpp"
#include "../../company_func.h"
#include "../../group.h"
-AIGroupList::AIGroupList()
+ScriptGroupList::ScriptGroupList()
{
Group *g;
FOR_ALL_GROUPS(g) {
@@ -7,14 +7,14 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file script_grouplist.cpp Implementation of AIGroupList and friends. */
+/** @file script_grouplist.cpp Implementation of ScriptGroupList and friends. */
#include "../../stdafx.h"
#include "script_grouplist.hpp"